# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKRegistrationCommonPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkPDEDeformableRegistrationFunctionPython
else:
    import _itkPDEDeformableRegistrationFunctionPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkCovariantVectorPython
import itk.vnl_vector_refPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_vectorPython
import itk.vnl_matrixPython
import itk.itkVectorPython
import itk.itkFixedArrayPython
import itk.itkPointPython
import itk.vnl_matrix_fixedPython
import itk.itkImagePython
import itk.itkImageRegionPython
import itk.itkIndexPython
import itk.itkSizePython
import itk.itkOffsetPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkRGBAPixelPython
import itk.itkRGBPixelPython
import itk.itkFiniteDifferenceFunctionPython
class itkPDEDeformableRegistrationFunctionIF2IF2IVF22(itk.itkFiniteDifferenceFunctionPython.itkFiniteDifferenceFunctionIVF22):
    r"""Proxy of C++ itkPDEDeformableRegistrationFunctionIF2IF2IVF22 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetMovingImage(self, ptr):
        r"""
        SetMovingImage(self, ptr)

        Parameters
        ----------
        ptr: itkImageF2 const *

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF2IF2IVF22_SetMovingImage(self, ptr)

    def GetMovingImage(self):
        r"""GetMovingImage(self) -> itkImageF2"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF2IF2IVF22_GetMovingImage(self)

    def SetFixedImage(self, ptr):
        r"""
        SetFixedImage(self, ptr)

        Parameters
        ----------
        ptr: itkImageF2 const *

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF2IF2IVF22_SetFixedImage(self, ptr)

    def GetFixedImage(self):
        r"""GetFixedImage(self) -> itkImageF2"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF2IF2IVF22_GetFixedImage(self)

    def SetDisplacementField(self, ptr):
        r"""
        SetDisplacementField(self, ptr)

        Parameters
        ----------
        ptr: itkImageVF22_Pointer

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF2IF2IVF22_SetDisplacementField(self, ptr)

    def GetDisplacementField(self):
        r"""GetDisplacementField(self) -> itkImageVF22"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF2IF2IVF22_GetDisplacementField(self)

    def SetEnergy(self, e):
        r"""
        SetEnergy(self, e)

        Parameters
        ----------
        e: double

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF2IF2IVF22_SetEnergy(self, e)

    def GetEnergy(self):
        r"""GetEnergy(self) -> double"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF2IF2IVF22_GetEnergy(self)

    def SetGradientStep(self, e):
        r"""
        SetGradientStep(self, e)

        Parameters
        ----------
        e: double

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF2IF2IVF22_SetGradientStep(self, e)

    def GetGradientStep(self):
        r"""GetGradientStep(self) -> double"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF2IF2IVF22_GetGradientStep(self)

    def SetNormalizeGradient(self, e):
        r"""
        SetNormalizeGradient(self, e)

        Parameters
        ----------
        e: bool

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF2IF2IVF22_SetNormalizeGradient(self, e)

    def GetNormalizeGradient(self):
        r"""GetNormalizeGradient(self) -> bool"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF2IF2IVF22_GetNormalizeGradient(self)
    __swig_destroy__ = _itkPDEDeformableRegistrationFunctionPython.delete_itkPDEDeformableRegistrationFunctionIF2IF2IVF22

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPDEDeformableRegistrationFunctionIF2IF2IVF22

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF2IF2IVF22_cast(obj)

# Register itkPDEDeformableRegistrationFunctionIF2IF2IVF22 in _itkPDEDeformableRegistrationFunctionPython:
_itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF2IF2IVF22_swigregister(itkPDEDeformableRegistrationFunctionIF2IF2IVF22)
class itkPDEDeformableRegistrationFunctionIF2IF2IVF32(itk.itkFiniteDifferenceFunctionPython.itkFiniteDifferenceFunctionIVF32):
    r"""Proxy of C++ itkPDEDeformableRegistrationFunctionIF2IF2IVF32 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetMovingImage(self, ptr):
        r"""
        SetMovingImage(self, ptr)

        Parameters
        ----------
        ptr: itkImageF2 const *

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF2IF2IVF32_SetMovingImage(self, ptr)

    def GetMovingImage(self):
        r"""GetMovingImage(self) -> itkImageF2"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF2IF2IVF32_GetMovingImage(self)

    def SetFixedImage(self, ptr):
        r"""
        SetFixedImage(self, ptr)

        Parameters
        ----------
        ptr: itkImageF2 const *

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF2IF2IVF32_SetFixedImage(self, ptr)

    def GetFixedImage(self):
        r"""GetFixedImage(self) -> itkImageF2"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF2IF2IVF32_GetFixedImage(self)

    def SetDisplacementField(self, ptr):
        r"""
        SetDisplacementField(self, ptr)

        Parameters
        ----------
        ptr: itkImageVF32_Pointer

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF2IF2IVF32_SetDisplacementField(self, ptr)

    def GetDisplacementField(self):
        r"""GetDisplacementField(self) -> itkImageVF32"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF2IF2IVF32_GetDisplacementField(self)

    def SetEnergy(self, e):
        r"""
        SetEnergy(self, e)

        Parameters
        ----------
        e: double

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF2IF2IVF32_SetEnergy(self, e)

    def GetEnergy(self):
        r"""GetEnergy(self) -> double"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF2IF2IVF32_GetEnergy(self)

    def SetGradientStep(self, e):
        r"""
        SetGradientStep(self, e)

        Parameters
        ----------
        e: double

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF2IF2IVF32_SetGradientStep(self, e)

    def GetGradientStep(self):
        r"""GetGradientStep(self) -> double"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF2IF2IVF32_GetGradientStep(self)

    def SetNormalizeGradient(self, e):
        r"""
        SetNormalizeGradient(self, e)

        Parameters
        ----------
        e: bool

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF2IF2IVF32_SetNormalizeGradient(self, e)

    def GetNormalizeGradient(self):
        r"""GetNormalizeGradient(self) -> bool"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF2IF2IVF32_GetNormalizeGradient(self)
    __swig_destroy__ = _itkPDEDeformableRegistrationFunctionPython.delete_itkPDEDeformableRegistrationFunctionIF2IF2IVF32

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPDEDeformableRegistrationFunctionIF2IF2IVF32

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF2IF2IVF32_cast(obj)

# Register itkPDEDeformableRegistrationFunctionIF2IF2IVF32 in _itkPDEDeformableRegistrationFunctionPython:
_itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF2IF2IVF32_swigregister(itkPDEDeformableRegistrationFunctionIF2IF2IVF32)
class itkPDEDeformableRegistrationFunctionIF2IF2IVF42(itk.itkFiniteDifferenceFunctionPython.itkFiniteDifferenceFunctionIVF42):
    r"""Proxy of C++ itkPDEDeformableRegistrationFunctionIF2IF2IVF42 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetMovingImage(self, ptr):
        r"""
        SetMovingImage(self, ptr)

        Parameters
        ----------
        ptr: itkImageF2 const *

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF2IF2IVF42_SetMovingImage(self, ptr)

    def GetMovingImage(self):
        r"""GetMovingImage(self) -> itkImageF2"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF2IF2IVF42_GetMovingImage(self)

    def SetFixedImage(self, ptr):
        r"""
        SetFixedImage(self, ptr)

        Parameters
        ----------
        ptr: itkImageF2 const *

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF2IF2IVF42_SetFixedImage(self, ptr)

    def GetFixedImage(self):
        r"""GetFixedImage(self) -> itkImageF2"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF2IF2IVF42_GetFixedImage(self)

    def SetDisplacementField(self, ptr):
        r"""
        SetDisplacementField(self, ptr)

        Parameters
        ----------
        ptr: itkImageVF42_Pointer

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF2IF2IVF42_SetDisplacementField(self, ptr)

    def GetDisplacementField(self):
        r"""GetDisplacementField(self) -> itkImageVF42"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF2IF2IVF42_GetDisplacementField(self)

    def SetEnergy(self, e):
        r"""
        SetEnergy(self, e)

        Parameters
        ----------
        e: double

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF2IF2IVF42_SetEnergy(self, e)

    def GetEnergy(self):
        r"""GetEnergy(self) -> double"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF2IF2IVF42_GetEnergy(self)

    def SetGradientStep(self, e):
        r"""
        SetGradientStep(self, e)

        Parameters
        ----------
        e: double

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF2IF2IVF42_SetGradientStep(self, e)

    def GetGradientStep(self):
        r"""GetGradientStep(self) -> double"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF2IF2IVF42_GetGradientStep(self)

    def SetNormalizeGradient(self, e):
        r"""
        SetNormalizeGradient(self, e)

        Parameters
        ----------
        e: bool

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF2IF2IVF42_SetNormalizeGradient(self, e)

    def GetNormalizeGradient(self):
        r"""GetNormalizeGradient(self) -> bool"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF2IF2IVF42_GetNormalizeGradient(self)
    __swig_destroy__ = _itkPDEDeformableRegistrationFunctionPython.delete_itkPDEDeformableRegistrationFunctionIF2IF2IVF42

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPDEDeformableRegistrationFunctionIF2IF2IVF42

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF2IF2IVF42_cast(obj)

# Register itkPDEDeformableRegistrationFunctionIF2IF2IVF42 in _itkPDEDeformableRegistrationFunctionPython:
_itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF2IF2IVF42_swigregister(itkPDEDeformableRegistrationFunctionIF2IF2IVF42)
class itkPDEDeformableRegistrationFunctionIF3IF3IVF23(itk.itkFiniteDifferenceFunctionPython.itkFiniteDifferenceFunctionIVF23):
    r"""Proxy of C++ itkPDEDeformableRegistrationFunctionIF3IF3IVF23 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetMovingImage(self, ptr):
        r"""
        SetMovingImage(self, ptr)

        Parameters
        ----------
        ptr: itkImageF3 const *

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF3IF3IVF23_SetMovingImage(self, ptr)

    def GetMovingImage(self):
        r"""GetMovingImage(self) -> itkImageF3"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF3IF3IVF23_GetMovingImage(self)

    def SetFixedImage(self, ptr):
        r"""
        SetFixedImage(self, ptr)

        Parameters
        ----------
        ptr: itkImageF3 const *

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF3IF3IVF23_SetFixedImage(self, ptr)

    def GetFixedImage(self):
        r"""GetFixedImage(self) -> itkImageF3"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF3IF3IVF23_GetFixedImage(self)

    def SetDisplacementField(self, ptr):
        r"""
        SetDisplacementField(self, ptr)

        Parameters
        ----------
        ptr: itkImageVF23_Pointer

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF3IF3IVF23_SetDisplacementField(self, ptr)

    def GetDisplacementField(self):
        r"""GetDisplacementField(self) -> itkImageVF23"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF3IF3IVF23_GetDisplacementField(self)

    def SetEnergy(self, e):
        r"""
        SetEnergy(self, e)

        Parameters
        ----------
        e: double

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF3IF3IVF23_SetEnergy(self, e)

    def GetEnergy(self):
        r"""GetEnergy(self) -> double"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF3IF3IVF23_GetEnergy(self)

    def SetGradientStep(self, e):
        r"""
        SetGradientStep(self, e)

        Parameters
        ----------
        e: double

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF3IF3IVF23_SetGradientStep(self, e)

    def GetGradientStep(self):
        r"""GetGradientStep(self) -> double"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF3IF3IVF23_GetGradientStep(self)

    def SetNormalizeGradient(self, e):
        r"""
        SetNormalizeGradient(self, e)

        Parameters
        ----------
        e: bool

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF3IF3IVF23_SetNormalizeGradient(self, e)

    def GetNormalizeGradient(self):
        r"""GetNormalizeGradient(self) -> bool"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF3IF3IVF23_GetNormalizeGradient(self)
    __swig_destroy__ = _itkPDEDeformableRegistrationFunctionPython.delete_itkPDEDeformableRegistrationFunctionIF3IF3IVF23

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPDEDeformableRegistrationFunctionIF3IF3IVF23

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF3IF3IVF23_cast(obj)

# Register itkPDEDeformableRegistrationFunctionIF3IF3IVF23 in _itkPDEDeformableRegistrationFunctionPython:
_itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF3IF3IVF23_swigregister(itkPDEDeformableRegistrationFunctionIF3IF3IVF23)
class itkPDEDeformableRegistrationFunctionIF3IF3IVF33(itk.itkFiniteDifferenceFunctionPython.itkFiniteDifferenceFunctionIVF33):
    r"""Proxy of C++ itkPDEDeformableRegistrationFunctionIF3IF3IVF33 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetMovingImage(self, ptr):
        r"""
        SetMovingImage(self, ptr)

        Parameters
        ----------
        ptr: itkImageF3 const *

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF3IF3IVF33_SetMovingImage(self, ptr)

    def GetMovingImage(self):
        r"""GetMovingImage(self) -> itkImageF3"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF3IF3IVF33_GetMovingImage(self)

    def SetFixedImage(self, ptr):
        r"""
        SetFixedImage(self, ptr)

        Parameters
        ----------
        ptr: itkImageF3 const *

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF3IF3IVF33_SetFixedImage(self, ptr)

    def GetFixedImage(self):
        r"""GetFixedImage(self) -> itkImageF3"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF3IF3IVF33_GetFixedImage(self)

    def SetDisplacementField(self, ptr):
        r"""
        SetDisplacementField(self, ptr)

        Parameters
        ----------
        ptr: itkImageVF33_Pointer

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF3IF3IVF33_SetDisplacementField(self, ptr)

    def GetDisplacementField(self):
        r"""GetDisplacementField(self) -> itkImageVF33"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF3IF3IVF33_GetDisplacementField(self)

    def SetEnergy(self, e):
        r"""
        SetEnergy(self, e)

        Parameters
        ----------
        e: double

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF3IF3IVF33_SetEnergy(self, e)

    def GetEnergy(self):
        r"""GetEnergy(self) -> double"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF3IF3IVF33_GetEnergy(self)

    def SetGradientStep(self, e):
        r"""
        SetGradientStep(self, e)

        Parameters
        ----------
        e: double

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF3IF3IVF33_SetGradientStep(self, e)

    def GetGradientStep(self):
        r"""GetGradientStep(self) -> double"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF3IF3IVF33_GetGradientStep(self)

    def SetNormalizeGradient(self, e):
        r"""
        SetNormalizeGradient(self, e)

        Parameters
        ----------
        e: bool

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF3IF3IVF33_SetNormalizeGradient(self, e)

    def GetNormalizeGradient(self):
        r"""GetNormalizeGradient(self) -> bool"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF3IF3IVF33_GetNormalizeGradient(self)
    __swig_destroy__ = _itkPDEDeformableRegistrationFunctionPython.delete_itkPDEDeformableRegistrationFunctionIF3IF3IVF33

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPDEDeformableRegistrationFunctionIF3IF3IVF33

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF3IF3IVF33_cast(obj)

# Register itkPDEDeformableRegistrationFunctionIF3IF3IVF33 in _itkPDEDeformableRegistrationFunctionPython:
_itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF3IF3IVF33_swigregister(itkPDEDeformableRegistrationFunctionIF3IF3IVF33)
class itkPDEDeformableRegistrationFunctionIF3IF3IVF43(itk.itkFiniteDifferenceFunctionPython.itkFiniteDifferenceFunctionIVF43):
    r"""Proxy of C++ itkPDEDeformableRegistrationFunctionIF3IF3IVF43 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetMovingImage(self, ptr):
        r"""
        SetMovingImage(self, ptr)

        Parameters
        ----------
        ptr: itkImageF3 const *

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF3IF3IVF43_SetMovingImage(self, ptr)

    def GetMovingImage(self):
        r"""GetMovingImage(self) -> itkImageF3"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF3IF3IVF43_GetMovingImage(self)

    def SetFixedImage(self, ptr):
        r"""
        SetFixedImage(self, ptr)

        Parameters
        ----------
        ptr: itkImageF3 const *

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF3IF3IVF43_SetFixedImage(self, ptr)

    def GetFixedImage(self):
        r"""GetFixedImage(self) -> itkImageF3"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF3IF3IVF43_GetFixedImage(self)

    def SetDisplacementField(self, ptr):
        r"""
        SetDisplacementField(self, ptr)

        Parameters
        ----------
        ptr: itkImageVF43_Pointer

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF3IF3IVF43_SetDisplacementField(self, ptr)

    def GetDisplacementField(self):
        r"""GetDisplacementField(self) -> itkImageVF43"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF3IF3IVF43_GetDisplacementField(self)

    def SetEnergy(self, e):
        r"""
        SetEnergy(self, e)

        Parameters
        ----------
        e: double

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF3IF3IVF43_SetEnergy(self, e)

    def GetEnergy(self):
        r"""GetEnergy(self) -> double"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF3IF3IVF43_GetEnergy(self)

    def SetGradientStep(self, e):
        r"""
        SetGradientStep(self, e)

        Parameters
        ----------
        e: double

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF3IF3IVF43_SetGradientStep(self, e)

    def GetGradientStep(self):
        r"""GetGradientStep(self) -> double"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF3IF3IVF43_GetGradientStep(self)

    def SetNormalizeGradient(self, e):
        r"""
        SetNormalizeGradient(self, e)

        Parameters
        ----------
        e: bool

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF3IF3IVF43_SetNormalizeGradient(self, e)

    def GetNormalizeGradient(self):
        r"""GetNormalizeGradient(self) -> bool"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF3IF3IVF43_GetNormalizeGradient(self)
    __swig_destroy__ = _itkPDEDeformableRegistrationFunctionPython.delete_itkPDEDeformableRegistrationFunctionIF3IF3IVF43

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPDEDeformableRegistrationFunctionIF3IF3IVF43

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF3IF3IVF43_cast(obj)

# Register itkPDEDeformableRegistrationFunctionIF3IF3IVF43 in _itkPDEDeformableRegistrationFunctionPython:
_itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIF3IF3IVF43_swigregister(itkPDEDeformableRegistrationFunctionIF3IF3IVF43)
class itkPDEDeformableRegistrationFunctionISS2ISS2IVF22(itk.itkFiniteDifferenceFunctionPython.itkFiniteDifferenceFunctionIVF22):
    r"""Proxy of C++ itkPDEDeformableRegistrationFunctionISS2ISS2IVF22 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetMovingImage(self, ptr):
        r"""
        SetMovingImage(self, ptr)

        Parameters
        ----------
        ptr: itkImageSS2 const *

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS2ISS2IVF22_SetMovingImage(self, ptr)

    def GetMovingImage(self):
        r"""GetMovingImage(self) -> itkImageSS2"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS2ISS2IVF22_GetMovingImage(self)

    def SetFixedImage(self, ptr):
        r"""
        SetFixedImage(self, ptr)

        Parameters
        ----------
        ptr: itkImageSS2 const *

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS2ISS2IVF22_SetFixedImage(self, ptr)

    def GetFixedImage(self):
        r"""GetFixedImage(self) -> itkImageSS2"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS2ISS2IVF22_GetFixedImage(self)

    def SetDisplacementField(self, ptr):
        r"""
        SetDisplacementField(self, ptr)

        Parameters
        ----------
        ptr: itkImageVF22_Pointer

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS2ISS2IVF22_SetDisplacementField(self, ptr)

    def GetDisplacementField(self):
        r"""GetDisplacementField(self) -> itkImageVF22"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS2ISS2IVF22_GetDisplacementField(self)

    def SetEnergy(self, e):
        r"""
        SetEnergy(self, e)

        Parameters
        ----------
        e: double

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS2ISS2IVF22_SetEnergy(self, e)

    def GetEnergy(self):
        r"""GetEnergy(self) -> double"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS2ISS2IVF22_GetEnergy(self)

    def SetGradientStep(self, e):
        r"""
        SetGradientStep(self, e)

        Parameters
        ----------
        e: double

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS2ISS2IVF22_SetGradientStep(self, e)

    def GetGradientStep(self):
        r"""GetGradientStep(self) -> double"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS2ISS2IVF22_GetGradientStep(self)

    def SetNormalizeGradient(self, e):
        r"""
        SetNormalizeGradient(self, e)

        Parameters
        ----------
        e: bool

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS2ISS2IVF22_SetNormalizeGradient(self, e)

    def GetNormalizeGradient(self):
        r"""GetNormalizeGradient(self) -> bool"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS2ISS2IVF22_GetNormalizeGradient(self)
    __swig_destroy__ = _itkPDEDeformableRegistrationFunctionPython.delete_itkPDEDeformableRegistrationFunctionISS2ISS2IVF22

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPDEDeformableRegistrationFunctionISS2ISS2IVF22

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS2ISS2IVF22_cast(obj)

# Register itkPDEDeformableRegistrationFunctionISS2ISS2IVF22 in _itkPDEDeformableRegistrationFunctionPython:
_itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS2ISS2IVF22_swigregister(itkPDEDeformableRegistrationFunctionISS2ISS2IVF22)
class itkPDEDeformableRegistrationFunctionISS2ISS2IVF32(itk.itkFiniteDifferenceFunctionPython.itkFiniteDifferenceFunctionIVF32):
    r"""Proxy of C++ itkPDEDeformableRegistrationFunctionISS2ISS2IVF32 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetMovingImage(self, ptr):
        r"""
        SetMovingImage(self, ptr)

        Parameters
        ----------
        ptr: itkImageSS2 const *

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS2ISS2IVF32_SetMovingImage(self, ptr)

    def GetMovingImage(self):
        r"""GetMovingImage(self) -> itkImageSS2"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS2ISS2IVF32_GetMovingImage(self)

    def SetFixedImage(self, ptr):
        r"""
        SetFixedImage(self, ptr)

        Parameters
        ----------
        ptr: itkImageSS2 const *

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS2ISS2IVF32_SetFixedImage(self, ptr)

    def GetFixedImage(self):
        r"""GetFixedImage(self) -> itkImageSS2"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS2ISS2IVF32_GetFixedImage(self)

    def SetDisplacementField(self, ptr):
        r"""
        SetDisplacementField(self, ptr)

        Parameters
        ----------
        ptr: itkImageVF32_Pointer

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS2ISS2IVF32_SetDisplacementField(self, ptr)

    def GetDisplacementField(self):
        r"""GetDisplacementField(self) -> itkImageVF32"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS2ISS2IVF32_GetDisplacementField(self)

    def SetEnergy(self, e):
        r"""
        SetEnergy(self, e)

        Parameters
        ----------
        e: double

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS2ISS2IVF32_SetEnergy(self, e)

    def GetEnergy(self):
        r"""GetEnergy(self) -> double"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS2ISS2IVF32_GetEnergy(self)

    def SetGradientStep(self, e):
        r"""
        SetGradientStep(self, e)

        Parameters
        ----------
        e: double

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS2ISS2IVF32_SetGradientStep(self, e)

    def GetGradientStep(self):
        r"""GetGradientStep(self) -> double"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS2ISS2IVF32_GetGradientStep(self)

    def SetNormalizeGradient(self, e):
        r"""
        SetNormalizeGradient(self, e)

        Parameters
        ----------
        e: bool

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS2ISS2IVF32_SetNormalizeGradient(self, e)

    def GetNormalizeGradient(self):
        r"""GetNormalizeGradient(self) -> bool"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS2ISS2IVF32_GetNormalizeGradient(self)
    __swig_destroy__ = _itkPDEDeformableRegistrationFunctionPython.delete_itkPDEDeformableRegistrationFunctionISS2ISS2IVF32

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPDEDeformableRegistrationFunctionISS2ISS2IVF32

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS2ISS2IVF32_cast(obj)

# Register itkPDEDeformableRegistrationFunctionISS2ISS2IVF32 in _itkPDEDeformableRegistrationFunctionPython:
_itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS2ISS2IVF32_swigregister(itkPDEDeformableRegistrationFunctionISS2ISS2IVF32)
class itkPDEDeformableRegistrationFunctionISS2ISS2IVF42(itk.itkFiniteDifferenceFunctionPython.itkFiniteDifferenceFunctionIVF42):
    r"""Proxy of C++ itkPDEDeformableRegistrationFunctionISS2ISS2IVF42 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetMovingImage(self, ptr):
        r"""
        SetMovingImage(self, ptr)

        Parameters
        ----------
        ptr: itkImageSS2 const *

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS2ISS2IVF42_SetMovingImage(self, ptr)

    def GetMovingImage(self):
        r"""GetMovingImage(self) -> itkImageSS2"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS2ISS2IVF42_GetMovingImage(self)

    def SetFixedImage(self, ptr):
        r"""
        SetFixedImage(self, ptr)

        Parameters
        ----------
        ptr: itkImageSS2 const *

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS2ISS2IVF42_SetFixedImage(self, ptr)

    def GetFixedImage(self):
        r"""GetFixedImage(self) -> itkImageSS2"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS2ISS2IVF42_GetFixedImage(self)

    def SetDisplacementField(self, ptr):
        r"""
        SetDisplacementField(self, ptr)

        Parameters
        ----------
        ptr: itkImageVF42_Pointer

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS2ISS2IVF42_SetDisplacementField(self, ptr)

    def GetDisplacementField(self):
        r"""GetDisplacementField(self) -> itkImageVF42"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS2ISS2IVF42_GetDisplacementField(self)

    def SetEnergy(self, e):
        r"""
        SetEnergy(self, e)

        Parameters
        ----------
        e: double

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS2ISS2IVF42_SetEnergy(self, e)

    def GetEnergy(self):
        r"""GetEnergy(self) -> double"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS2ISS2IVF42_GetEnergy(self)

    def SetGradientStep(self, e):
        r"""
        SetGradientStep(self, e)

        Parameters
        ----------
        e: double

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS2ISS2IVF42_SetGradientStep(self, e)

    def GetGradientStep(self):
        r"""GetGradientStep(self) -> double"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS2ISS2IVF42_GetGradientStep(self)

    def SetNormalizeGradient(self, e):
        r"""
        SetNormalizeGradient(self, e)

        Parameters
        ----------
        e: bool

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS2ISS2IVF42_SetNormalizeGradient(self, e)

    def GetNormalizeGradient(self):
        r"""GetNormalizeGradient(self) -> bool"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS2ISS2IVF42_GetNormalizeGradient(self)
    __swig_destroy__ = _itkPDEDeformableRegistrationFunctionPython.delete_itkPDEDeformableRegistrationFunctionISS2ISS2IVF42

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPDEDeformableRegistrationFunctionISS2ISS2IVF42

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS2ISS2IVF42_cast(obj)

# Register itkPDEDeformableRegistrationFunctionISS2ISS2IVF42 in _itkPDEDeformableRegistrationFunctionPython:
_itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS2ISS2IVF42_swigregister(itkPDEDeformableRegistrationFunctionISS2ISS2IVF42)
class itkPDEDeformableRegistrationFunctionISS3ISS3IVF23(itk.itkFiniteDifferenceFunctionPython.itkFiniteDifferenceFunctionIVF23):
    r"""Proxy of C++ itkPDEDeformableRegistrationFunctionISS3ISS3IVF23 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetMovingImage(self, ptr):
        r"""
        SetMovingImage(self, ptr)

        Parameters
        ----------
        ptr: itkImageSS3 const *

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS3ISS3IVF23_SetMovingImage(self, ptr)

    def GetMovingImage(self):
        r"""GetMovingImage(self) -> itkImageSS3"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS3ISS3IVF23_GetMovingImage(self)

    def SetFixedImage(self, ptr):
        r"""
        SetFixedImage(self, ptr)

        Parameters
        ----------
        ptr: itkImageSS3 const *

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS3ISS3IVF23_SetFixedImage(self, ptr)

    def GetFixedImage(self):
        r"""GetFixedImage(self) -> itkImageSS3"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS3ISS3IVF23_GetFixedImage(self)

    def SetDisplacementField(self, ptr):
        r"""
        SetDisplacementField(self, ptr)

        Parameters
        ----------
        ptr: itkImageVF23_Pointer

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS3ISS3IVF23_SetDisplacementField(self, ptr)

    def GetDisplacementField(self):
        r"""GetDisplacementField(self) -> itkImageVF23"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS3ISS3IVF23_GetDisplacementField(self)

    def SetEnergy(self, e):
        r"""
        SetEnergy(self, e)

        Parameters
        ----------
        e: double

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS3ISS3IVF23_SetEnergy(self, e)

    def GetEnergy(self):
        r"""GetEnergy(self) -> double"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS3ISS3IVF23_GetEnergy(self)

    def SetGradientStep(self, e):
        r"""
        SetGradientStep(self, e)

        Parameters
        ----------
        e: double

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS3ISS3IVF23_SetGradientStep(self, e)

    def GetGradientStep(self):
        r"""GetGradientStep(self) -> double"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS3ISS3IVF23_GetGradientStep(self)

    def SetNormalizeGradient(self, e):
        r"""
        SetNormalizeGradient(self, e)

        Parameters
        ----------
        e: bool

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS3ISS3IVF23_SetNormalizeGradient(self, e)

    def GetNormalizeGradient(self):
        r"""GetNormalizeGradient(self) -> bool"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS3ISS3IVF23_GetNormalizeGradient(self)
    __swig_destroy__ = _itkPDEDeformableRegistrationFunctionPython.delete_itkPDEDeformableRegistrationFunctionISS3ISS3IVF23

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPDEDeformableRegistrationFunctionISS3ISS3IVF23

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS3ISS3IVF23_cast(obj)

# Register itkPDEDeformableRegistrationFunctionISS3ISS3IVF23 in _itkPDEDeformableRegistrationFunctionPython:
_itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS3ISS3IVF23_swigregister(itkPDEDeformableRegistrationFunctionISS3ISS3IVF23)
class itkPDEDeformableRegistrationFunctionISS3ISS3IVF33(itk.itkFiniteDifferenceFunctionPython.itkFiniteDifferenceFunctionIVF33):
    r"""Proxy of C++ itkPDEDeformableRegistrationFunctionISS3ISS3IVF33 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetMovingImage(self, ptr):
        r"""
        SetMovingImage(self, ptr)

        Parameters
        ----------
        ptr: itkImageSS3 const *

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS3ISS3IVF33_SetMovingImage(self, ptr)

    def GetMovingImage(self):
        r"""GetMovingImage(self) -> itkImageSS3"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS3ISS3IVF33_GetMovingImage(self)

    def SetFixedImage(self, ptr):
        r"""
        SetFixedImage(self, ptr)

        Parameters
        ----------
        ptr: itkImageSS3 const *

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS3ISS3IVF33_SetFixedImage(self, ptr)

    def GetFixedImage(self):
        r"""GetFixedImage(self) -> itkImageSS3"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS3ISS3IVF33_GetFixedImage(self)

    def SetDisplacementField(self, ptr):
        r"""
        SetDisplacementField(self, ptr)

        Parameters
        ----------
        ptr: itkImageVF33_Pointer

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS3ISS3IVF33_SetDisplacementField(self, ptr)

    def GetDisplacementField(self):
        r"""GetDisplacementField(self) -> itkImageVF33"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS3ISS3IVF33_GetDisplacementField(self)

    def SetEnergy(self, e):
        r"""
        SetEnergy(self, e)

        Parameters
        ----------
        e: double

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS3ISS3IVF33_SetEnergy(self, e)

    def GetEnergy(self):
        r"""GetEnergy(self) -> double"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS3ISS3IVF33_GetEnergy(self)

    def SetGradientStep(self, e):
        r"""
        SetGradientStep(self, e)

        Parameters
        ----------
        e: double

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS3ISS3IVF33_SetGradientStep(self, e)

    def GetGradientStep(self):
        r"""GetGradientStep(self) -> double"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS3ISS3IVF33_GetGradientStep(self)

    def SetNormalizeGradient(self, e):
        r"""
        SetNormalizeGradient(self, e)

        Parameters
        ----------
        e: bool

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS3ISS3IVF33_SetNormalizeGradient(self, e)

    def GetNormalizeGradient(self):
        r"""GetNormalizeGradient(self) -> bool"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS3ISS3IVF33_GetNormalizeGradient(self)
    __swig_destroy__ = _itkPDEDeformableRegistrationFunctionPython.delete_itkPDEDeformableRegistrationFunctionISS3ISS3IVF33

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPDEDeformableRegistrationFunctionISS3ISS3IVF33

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS3ISS3IVF33_cast(obj)

# Register itkPDEDeformableRegistrationFunctionISS3ISS3IVF33 in _itkPDEDeformableRegistrationFunctionPython:
_itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS3ISS3IVF33_swigregister(itkPDEDeformableRegistrationFunctionISS3ISS3IVF33)
class itkPDEDeformableRegistrationFunctionISS3ISS3IVF43(itk.itkFiniteDifferenceFunctionPython.itkFiniteDifferenceFunctionIVF43):
    r"""Proxy of C++ itkPDEDeformableRegistrationFunctionISS3ISS3IVF43 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetMovingImage(self, ptr):
        r"""
        SetMovingImage(self, ptr)

        Parameters
        ----------
        ptr: itkImageSS3 const *

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS3ISS3IVF43_SetMovingImage(self, ptr)

    def GetMovingImage(self):
        r"""GetMovingImage(self) -> itkImageSS3"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS3ISS3IVF43_GetMovingImage(self)

    def SetFixedImage(self, ptr):
        r"""
        SetFixedImage(self, ptr)

        Parameters
        ----------
        ptr: itkImageSS3 const *

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS3ISS3IVF43_SetFixedImage(self, ptr)

    def GetFixedImage(self):
        r"""GetFixedImage(self) -> itkImageSS3"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS3ISS3IVF43_GetFixedImage(self)

    def SetDisplacementField(self, ptr):
        r"""
        SetDisplacementField(self, ptr)

        Parameters
        ----------
        ptr: itkImageVF43_Pointer

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS3ISS3IVF43_SetDisplacementField(self, ptr)

    def GetDisplacementField(self):
        r"""GetDisplacementField(self) -> itkImageVF43"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS3ISS3IVF43_GetDisplacementField(self)

    def SetEnergy(self, e):
        r"""
        SetEnergy(self, e)

        Parameters
        ----------
        e: double

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS3ISS3IVF43_SetEnergy(self, e)

    def GetEnergy(self):
        r"""GetEnergy(self) -> double"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS3ISS3IVF43_GetEnergy(self)

    def SetGradientStep(self, e):
        r"""
        SetGradientStep(self, e)

        Parameters
        ----------
        e: double

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS3ISS3IVF43_SetGradientStep(self, e)

    def GetGradientStep(self):
        r"""GetGradientStep(self) -> double"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS3ISS3IVF43_GetGradientStep(self)

    def SetNormalizeGradient(self, e):
        r"""
        SetNormalizeGradient(self, e)

        Parameters
        ----------
        e: bool

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS3ISS3IVF43_SetNormalizeGradient(self, e)

    def GetNormalizeGradient(self):
        r"""GetNormalizeGradient(self) -> bool"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS3ISS3IVF43_GetNormalizeGradient(self)
    __swig_destroy__ = _itkPDEDeformableRegistrationFunctionPython.delete_itkPDEDeformableRegistrationFunctionISS3ISS3IVF43

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPDEDeformableRegistrationFunctionISS3ISS3IVF43

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS3ISS3IVF43_cast(obj)

# Register itkPDEDeformableRegistrationFunctionISS3ISS3IVF43 in _itkPDEDeformableRegistrationFunctionPython:
_itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionISS3ISS3IVF43_swigregister(itkPDEDeformableRegistrationFunctionISS3ISS3IVF43)
class itkPDEDeformableRegistrationFunctionIUC2IUC2IVF22(itk.itkFiniteDifferenceFunctionPython.itkFiniteDifferenceFunctionIVF22):
    r"""Proxy of C++ itkPDEDeformableRegistrationFunctionIUC2IUC2IVF22 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetMovingImage(self, ptr):
        r"""
        SetMovingImage(self, ptr)

        Parameters
        ----------
        ptr: itkImageUC2 const *

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC2IUC2IVF22_SetMovingImage(self, ptr)

    def GetMovingImage(self):
        r"""GetMovingImage(self) -> itkImageUC2"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC2IUC2IVF22_GetMovingImage(self)

    def SetFixedImage(self, ptr):
        r"""
        SetFixedImage(self, ptr)

        Parameters
        ----------
        ptr: itkImageUC2 const *

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC2IUC2IVF22_SetFixedImage(self, ptr)

    def GetFixedImage(self):
        r"""GetFixedImage(self) -> itkImageUC2"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC2IUC2IVF22_GetFixedImage(self)

    def SetDisplacementField(self, ptr):
        r"""
        SetDisplacementField(self, ptr)

        Parameters
        ----------
        ptr: itkImageVF22_Pointer

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC2IUC2IVF22_SetDisplacementField(self, ptr)

    def GetDisplacementField(self):
        r"""GetDisplacementField(self) -> itkImageVF22"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC2IUC2IVF22_GetDisplacementField(self)

    def SetEnergy(self, e):
        r"""
        SetEnergy(self, e)

        Parameters
        ----------
        e: double

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC2IUC2IVF22_SetEnergy(self, e)

    def GetEnergy(self):
        r"""GetEnergy(self) -> double"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC2IUC2IVF22_GetEnergy(self)

    def SetGradientStep(self, e):
        r"""
        SetGradientStep(self, e)

        Parameters
        ----------
        e: double

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC2IUC2IVF22_SetGradientStep(self, e)

    def GetGradientStep(self):
        r"""GetGradientStep(self) -> double"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC2IUC2IVF22_GetGradientStep(self)

    def SetNormalizeGradient(self, e):
        r"""
        SetNormalizeGradient(self, e)

        Parameters
        ----------
        e: bool

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC2IUC2IVF22_SetNormalizeGradient(self, e)

    def GetNormalizeGradient(self):
        r"""GetNormalizeGradient(self) -> bool"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC2IUC2IVF22_GetNormalizeGradient(self)
    __swig_destroy__ = _itkPDEDeformableRegistrationFunctionPython.delete_itkPDEDeformableRegistrationFunctionIUC2IUC2IVF22

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPDEDeformableRegistrationFunctionIUC2IUC2IVF22

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC2IUC2IVF22_cast(obj)

# Register itkPDEDeformableRegistrationFunctionIUC2IUC2IVF22 in _itkPDEDeformableRegistrationFunctionPython:
_itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC2IUC2IVF22_swigregister(itkPDEDeformableRegistrationFunctionIUC2IUC2IVF22)
class itkPDEDeformableRegistrationFunctionIUC2IUC2IVF32(itk.itkFiniteDifferenceFunctionPython.itkFiniteDifferenceFunctionIVF32):
    r"""Proxy of C++ itkPDEDeformableRegistrationFunctionIUC2IUC2IVF32 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetMovingImage(self, ptr):
        r"""
        SetMovingImage(self, ptr)

        Parameters
        ----------
        ptr: itkImageUC2 const *

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC2IUC2IVF32_SetMovingImage(self, ptr)

    def GetMovingImage(self):
        r"""GetMovingImage(self) -> itkImageUC2"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC2IUC2IVF32_GetMovingImage(self)

    def SetFixedImage(self, ptr):
        r"""
        SetFixedImage(self, ptr)

        Parameters
        ----------
        ptr: itkImageUC2 const *

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC2IUC2IVF32_SetFixedImage(self, ptr)

    def GetFixedImage(self):
        r"""GetFixedImage(self) -> itkImageUC2"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC2IUC2IVF32_GetFixedImage(self)

    def SetDisplacementField(self, ptr):
        r"""
        SetDisplacementField(self, ptr)

        Parameters
        ----------
        ptr: itkImageVF32_Pointer

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC2IUC2IVF32_SetDisplacementField(self, ptr)

    def GetDisplacementField(self):
        r"""GetDisplacementField(self) -> itkImageVF32"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC2IUC2IVF32_GetDisplacementField(self)

    def SetEnergy(self, e):
        r"""
        SetEnergy(self, e)

        Parameters
        ----------
        e: double

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC2IUC2IVF32_SetEnergy(self, e)

    def GetEnergy(self):
        r"""GetEnergy(self) -> double"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC2IUC2IVF32_GetEnergy(self)

    def SetGradientStep(self, e):
        r"""
        SetGradientStep(self, e)

        Parameters
        ----------
        e: double

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC2IUC2IVF32_SetGradientStep(self, e)

    def GetGradientStep(self):
        r"""GetGradientStep(self) -> double"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC2IUC2IVF32_GetGradientStep(self)

    def SetNormalizeGradient(self, e):
        r"""
        SetNormalizeGradient(self, e)

        Parameters
        ----------
        e: bool

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC2IUC2IVF32_SetNormalizeGradient(self, e)

    def GetNormalizeGradient(self):
        r"""GetNormalizeGradient(self) -> bool"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC2IUC2IVF32_GetNormalizeGradient(self)
    __swig_destroy__ = _itkPDEDeformableRegistrationFunctionPython.delete_itkPDEDeformableRegistrationFunctionIUC2IUC2IVF32

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPDEDeformableRegistrationFunctionIUC2IUC2IVF32

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC2IUC2IVF32_cast(obj)

# Register itkPDEDeformableRegistrationFunctionIUC2IUC2IVF32 in _itkPDEDeformableRegistrationFunctionPython:
_itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC2IUC2IVF32_swigregister(itkPDEDeformableRegistrationFunctionIUC2IUC2IVF32)
class itkPDEDeformableRegistrationFunctionIUC2IUC2IVF42(itk.itkFiniteDifferenceFunctionPython.itkFiniteDifferenceFunctionIVF42):
    r"""Proxy of C++ itkPDEDeformableRegistrationFunctionIUC2IUC2IVF42 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetMovingImage(self, ptr):
        r"""
        SetMovingImage(self, ptr)

        Parameters
        ----------
        ptr: itkImageUC2 const *

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC2IUC2IVF42_SetMovingImage(self, ptr)

    def GetMovingImage(self):
        r"""GetMovingImage(self) -> itkImageUC2"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC2IUC2IVF42_GetMovingImage(self)

    def SetFixedImage(self, ptr):
        r"""
        SetFixedImage(self, ptr)

        Parameters
        ----------
        ptr: itkImageUC2 const *

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC2IUC2IVF42_SetFixedImage(self, ptr)

    def GetFixedImage(self):
        r"""GetFixedImage(self) -> itkImageUC2"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC2IUC2IVF42_GetFixedImage(self)

    def SetDisplacementField(self, ptr):
        r"""
        SetDisplacementField(self, ptr)

        Parameters
        ----------
        ptr: itkImageVF42_Pointer

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC2IUC2IVF42_SetDisplacementField(self, ptr)

    def GetDisplacementField(self):
        r"""GetDisplacementField(self) -> itkImageVF42"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC2IUC2IVF42_GetDisplacementField(self)

    def SetEnergy(self, e):
        r"""
        SetEnergy(self, e)

        Parameters
        ----------
        e: double

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC2IUC2IVF42_SetEnergy(self, e)

    def GetEnergy(self):
        r"""GetEnergy(self) -> double"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC2IUC2IVF42_GetEnergy(self)

    def SetGradientStep(self, e):
        r"""
        SetGradientStep(self, e)

        Parameters
        ----------
        e: double

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC2IUC2IVF42_SetGradientStep(self, e)

    def GetGradientStep(self):
        r"""GetGradientStep(self) -> double"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC2IUC2IVF42_GetGradientStep(self)

    def SetNormalizeGradient(self, e):
        r"""
        SetNormalizeGradient(self, e)

        Parameters
        ----------
        e: bool

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC2IUC2IVF42_SetNormalizeGradient(self, e)

    def GetNormalizeGradient(self):
        r"""GetNormalizeGradient(self) -> bool"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC2IUC2IVF42_GetNormalizeGradient(self)
    __swig_destroy__ = _itkPDEDeformableRegistrationFunctionPython.delete_itkPDEDeformableRegistrationFunctionIUC2IUC2IVF42

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPDEDeformableRegistrationFunctionIUC2IUC2IVF42

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC2IUC2IVF42_cast(obj)

# Register itkPDEDeformableRegistrationFunctionIUC2IUC2IVF42 in _itkPDEDeformableRegistrationFunctionPython:
_itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC2IUC2IVF42_swigregister(itkPDEDeformableRegistrationFunctionIUC2IUC2IVF42)
class itkPDEDeformableRegistrationFunctionIUC3IUC3IVF23(itk.itkFiniteDifferenceFunctionPython.itkFiniteDifferenceFunctionIVF23):
    r"""Proxy of C++ itkPDEDeformableRegistrationFunctionIUC3IUC3IVF23 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetMovingImage(self, ptr):
        r"""
        SetMovingImage(self, ptr)

        Parameters
        ----------
        ptr: itkImageUC3 const *

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC3IUC3IVF23_SetMovingImage(self, ptr)

    def GetMovingImage(self):
        r"""GetMovingImage(self) -> itkImageUC3"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC3IUC3IVF23_GetMovingImage(self)

    def SetFixedImage(self, ptr):
        r"""
        SetFixedImage(self, ptr)

        Parameters
        ----------
        ptr: itkImageUC3 const *

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC3IUC3IVF23_SetFixedImage(self, ptr)

    def GetFixedImage(self):
        r"""GetFixedImage(self) -> itkImageUC3"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC3IUC3IVF23_GetFixedImage(self)

    def SetDisplacementField(self, ptr):
        r"""
        SetDisplacementField(self, ptr)

        Parameters
        ----------
        ptr: itkImageVF23_Pointer

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC3IUC3IVF23_SetDisplacementField(self, ptr)

    def GetDisplacementField(self):
        r"""GetDisplacementField(self) -> itkImageVF23"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC3IUC3IVF23_GetDisplacementField(self)

    def SetEnergy(self, e):
        r"""
        SetEnergy(self, e)

        Parameters
        ----------
        e: double

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC3IUC3IVF23_SetEnergy(self, e)

    def GetEnergy(self):
        r"""GetEnergy(self) -> double"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC3IUC3IVF23_GetEnergy(self)

    def SetGradientStep(self, e):
        r"""
        SetGradientStep(self, e)

        Parameters
        ----------
        e: double

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC3IUC3IVF23_SetGradientStep(self, e)

    def GetGradientStep(self):
        r"""GetGradientStep(self) -> double"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC3IUC3IVF23_GetGradientStep(self)

    def SetNormalizeGradient(self, e):
        r"""
        SetNormalizeGradient(self, e)

        Parameters
        ----------
        e: bool

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC3IUC3IVF23_SetNormalizeGradient(self, e)

    def GetNormalizeGradient(self):
        r"""GetNormalizeGradient(self) -> bool"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC3IUC3IVF23_GetNormalizeGradient(self)
    __swig_destroy__ = _itkPDEDeformableRegistrationFunctionPython.delete_itkPDEDeformableRegistrationFunctionIUC3IUC3IVF23

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPDEDeformableRegistrationFunctionIUC3IUC3IVF23

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC3IUC3IVF23_cast(obj)

# Register itkPDEDeformableRegistrationFunctionIUC3IUC3IVF23 in _itkPDEDeformableRegistrationFunctionPython:
_itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC3IUC3IVF23_swigregister(itkPDEDeformableRegistrationFunctionIUC3IUC3IVF23)
class itkPDEDeformableRegistrationFunctionIUC3IUC3IVF33(itk.itkFiniteDifferenceFunctionPython.itkFiniteDifferenceFunctionIVF33):
    r"""Proxy of C++ itkPDEDeformableRegistrationFunctionIUC3IUC3IVF33 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetMovingImage(self, ptr):
        r"""
        SetMovingImage(self, ptr)

        Parameters
        ----------
        ptr: itkImageUC3 const *

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC3IUC3IVF33_SetMovingImage(self, ptr)

    def GetMovingImage(self):
        r"""GetMovingImage(self) -> itkImageUC3"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC3IUC3IVF33_GetMovingImage(self)

    def SetFixedImage(self, ptr):
        r"""
        SetFixedImage(self, ptr)

        Parameters
        ----------
        ptr: itkImageUC3 const *

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC3IUC3IVF33_SetFixedImage(self, ptr)

    def GetFixedImage(self):
        r"""GetFixedImage(self) -> itkImageUC3"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC3IUC3IVF33_GetFixedImage(self)

    def SetDisplacementField(self, ptr):
        r"""
        SetDisplacementField(self, ptr)

        Parameters
        ----------
        ptr: itkImageVF33_Pointer

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC3IUC3IVF33_SetDisplacementField(self, ptr)

    def GetDisplacementField(self):
        r"""GetDisplacementField(self) -> itkImageVF33"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC3IUC3IVF33_GetDisplacementField(self)

    def SetEnergy(self, e):
        r"""
        SetEnergy(self, e)

        Parameters
        ----------
        e: double

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC3IUC3IVF33_SetEnergy(self, e)

    def GetEnergy(self):
        r"""GetEnergy(self) -> double"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC3IUC3IVF33_GetEnergy(self)

    def SetGradientStep(self, e):
        r"""
        SetGradientStep(self, e)

        Parameters
        ----------
        e: double

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC3IUC3IVF33_SetGradientStep(self, e)

    def GetGradientStep(self):
        r"""GetGradientStep(self) -> double"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC3IUC3IVF33_GetGradientStep(self)

    def SetNormalizeGradient(self, e):
        r"""
        SetNormalizeGradient(self, e)

        Parameters
        ----------
        e: bool

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC3IUC3IVF33_SetNormalizeGradient(self, e)

    def GetNormalizeGradient(self):
        r"""GetNormalizeGradient(self) -> bool"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC3IUC3IVF33_GetNormalizeGradient(self)
    __swig_destroy__ = _itkPDEDeformableRegistrationFunctionPython.delete_itkPDEDeformableRegistrationFunctionIUC3IUC3IVF33

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPDEDeformableRegistrationFunctionIUC3IUC3IVF33

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC3IUC3IVF33_cast(obj)

# Register itkPDEDeformableRegistrationFunctionIUC3IUC3IVF33 in _itkPDEDeformableRegistrationFunctionPython:
_itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC3IUC3IVF33_swigregister(itkPDEDeformableRegistrationFunctionIUC3IUC3IVF33)
class itkPDEDeformableRegistrationFunctionIUC3IUC3IVF43(itk.itkFiniteDifferenceFunctionPython.itkFiniteDifferenceFunctionIVF43):
    r"""Proxy of C++ itkPDEDeformableRegistrationFunctionIUC3IUC3IVF43 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetMovingImage(self, ptr):
        r"""
        SetMovingImage(self, ptr)

        Parameters
        ----------
        ptr: itkImageUC3 const *

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC3IUC3IVF43_SetMovingImage(self, ptr)

    def GetMovingImage(self):
        r"""GetMovingImage(self) -> itkImageUC3"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC3IUC3IVF43_GetMovingImage(self)

    def SetFixedImage(self, ptr):
        r"""
        SetFixedImage(self, ptr)

        Parameters
        ----------
        ptr: itkImageUC3 const *

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC3IUC3IVF43_SetFixedImage(self, ptr)

    def GetFixedImage(self):
        r"""GetFixedImage(self) -> itkImageUC3"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC3IUC3IVF43_GetFixedImage(self)

    def SetDisplacementField(self, ptr):
        r"""
        SetDisplacementField(self, ptr)

        Parameters
        ----------
        ptr: itkImageVF43_Pointer

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC3IUC3IVF43_SetDisplacementField(self, ptr)

    def GetDisplacementField(self):
        r"""GetDisplacementField(self) -> itkImageVF43"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC3IUC3IVF43_GetDisplacementField(self)

    def SetEnergy(self, e):
        r"""
        SetEnergy(self, e)

        Parameters
        ----------
        e: double

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC3IUC3IVF43_SetEnergy(self, e)

    def GetEnergy(self):
        r"""GetEnergy(self) -> double"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC3IUC3IVF43_GetEnergy(self)

    def SetGradientStep(self, e):
        r"""
        SetGradientStep(self, e)

        Parameters
        ----------
        e: double

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC3IUC3IVF43_SetGradientStep(self, e)

    def GetGradientStep(self):
        r"""GetGradientStep(self) -> double"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC3IUC3IVF43_GetGradientStep(self)

    def SetNormalizeGradient(self, e):
        r"""
        SetNormalizeGradient(self, e)

        Parameters
        ----------
        e: bool

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC3IUC3IVF43_SetNormalizeGradient(self, e)

    def GetNormalizeGradient(self):
        r"""GetNormalizeGradient(self) -> bool"""
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC3IUC3IVF43_GetNormalizeGradient(self)
    __swig_destroy__ = _itkPDEDeformableRegistrationFunctionPython.delete_itkPDEDeformableRegistrationFunctionIUC3IUC3IVF43

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPDEDeformableRegistrationFunctionIUC3IUC3IVF43

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC3IUC3IVF43_cast(obj)

# Register itkPDEDeformableRegistrationFunctionIUC3IUC3IVF43 in _itkPDEDeformableRegistrationFunctionPython:
_itkPDEDeformableRegistrationFunctionPython.itkPDEDeformableRegistrationFunctionIUC3IUC3IVF43_swigregister(itkPDEDeformableRegistrationFunctionIUC3IUC3IVF43)

